@@ -14,6 +14,7 @@ from torchvision.datasets import ImageFolder
 from . import registry
 from .base_anno import BaseAnno
 from ..util.logger import setup_logger
+from ..util.misc import get_cpu_count
 
 
 def raw_reader(path):
@@ -38,9 +39,9 @@ class PytorchImageFolder(BaseAnno):
     def process(self) -> dict:
         image_path = os.path.join(self.src_dir, self.image_folder)
         data_set = ImageFolder(image_path, loader=raw_reader)
-        data_loader = DataLoader(data_set, num_workers=0)
+        data_loader = DataLoader(data_set, num_workers=int(get_cpu_count() / 2))
 
-        return {'dataloader': data_loader}
+        return {'dataloader': data_loader, 'classes': data_set.classes}
 
     def save(self, input_data: dict):
         super(PytorchImageFolder, self).save(input_data)
